==> core-1.0.2.tgz: package/lib/fields/fileField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as FilePond from 'filepond';
import { Field } from '../field.js';
import { debounce } from '../utils.js';
export class FileField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'file',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            className: 'form-input',
            enhance: true,
            multiple: false,
            debounce: 50,
            options: {
                storeAsFile: true,
                instantUpload: false,
                allowProcess: false,
            },
        };
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
            this.initFilepond();
            this.bindChange();
        });
    }
    syncValue() { }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        this.inputElement.className = this.options.className;
        if (this.options.multiple && !this.options.enhance)
            this.inputElement.setAttribute('multiple', 'true');
        if (this.options.accept)
            this.inputElement.setAttribute('accept', this.options.accept);
    }
    getFilepond() {
        return this._filepond;
    }
    initFilepond() {
        if (this.inputElement && this.options.enhance)
            this._filepond = FilePond.create(this.inputElement, this.options.options || {});
    }
    bindChange() {
        var _a;
        if (this.options.enhance) {
            this._filepond.on('addfile', (error, file) => {
                if (error)
                    return;
                const files = this._filepond.getFile();
                this.change(files);
            });
            this._filepond.on('removefile', (error, file) => {
                if (error)
                    return;
                const files = this._filepond.getFile();
                this.change(files);
            });
            this._filepond.on('updatefiles', (error, file) => {
                if (error)
                    return;
                const files = this._filepond.getFile();
                this.change(files);
            });
        }
        else {
            (_a = this.inputElement) === null || _a === void 0 ? void 0 : _a.addEventListener('change', debounce(this.coreChange, this.options.debounce, this));
        }
    }
    change(files) {
        this.setValue(files);
        if (this.options.change)
            this.options.change(this.getValue());
        this.validate();
    }
    coreChange(event) {
        if (event.target.files)
            this.change(event.target.files);
    }
}

==> core-1.0.13.tgz: package/lib/fields/fileField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as FilePond from 'filepond';
import { Field } from '../field.js';
import { debounce } from '../utils.js';
export class FileField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'file',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            className: 'form-input',
            enhance: true,
            multiple: false,
            debounce: 50,
            options: {
                storeAsFile: true,
                instantUpload: false,
                allowProcess: false,
            },
        };
        this._filepond = null;
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
            this.initFilepond();
            this.bindChange();
        });
    }
    initializeOptions(options) {
        this.options = Object.assign({}, Object.assign(Object.assign({}, this.options), {
            options: { allowMultiple: options.multiple, }
        }), options);
    }
    syncValue() {
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        if (this.options.placeholder)
            this.inputElement.setAttribute('placeholder', this.options.placeholder);
        this.inputElement.className = this.options.className;
        if (this.options.multiple && !this.options.enhance)
            this.inputElement.setAttribute('multiple', 'true');
        if (this.options.accept)
            this.inputElement.setAttribute('accept', this.options.accept);
    }
    getFilepond() {
        return this._filepond;
    }
    initFilepond() {
        if (this.inputElement && this.options.enhance)
            this._filepond = FilePond.create(this.inputElement, this.options.options || {});
    }
    bindChange() {
        var _a;
        if (this.options.enhance) {
            if (!this._filepond)
                return;
            this._filepond.on('addfile', (error, file) => {
                if (error)
                    return;
                console.log(this._filepond.getFiles());
                const files = this._filepond.getFiles();
                this.filePondChange(files);
            });
            this._filepond.on('removefile', (error, file) => {
                if (error)
                    return;
                const files = this._filepond.getFiles();
                this.filePondChange(files);
            });
            this._filepond.on('updatefiles', (error, file) => {
                if (error)
                    return;
                const files = this._filepond.getFiles();
                this.filePondChange(files);
            });
        }
        else {
            (_a = this.inputElement) === null || _a === void 0 ? void 0 : _a.addEventListener('change', debounce(this.change, this.options.debounce, this));
        }
    }
    filePondChange(files) {
        this.setValue(files);
        if (this.options.change)
            this.options.change(this.getValue());
        this.validate();
    }
    change(event) {
        if (event.target.files)
            this.change(event.target.files);
    }
}
